{% if report.scheduled_operations %}
<table class="table" width="100%">
    <tbody>
{% for item in report.scheduled_operations %}  
	<tr>
	    <td width="100%"><a href="skg://skrooge_scheduled_plugin/?selection={{ item.2 }}">{% if item.0 %}<b>{{ item.1 }}</b>{% else %}{{ item.1 }}{% endif %}</a></td>
	    <td align="right">{% if item.2 %}<a href="skg://skip_scheduled_operations/?selection={{ item.2 }}">[Skip]</a>{% endif %}</td>
	</tr>     
{% endfor %}     
    </tbody>
</table>  
{% else %}  
{{ msg_no_scheduled|safe }}
{% endif %}  
