{% if report.portfolio|length %}
<table id="table_portfolio" class="table">
    <thead>
    <tr class="tabletitle">
	<th align="center">{{ report.portfolio.0.1 }}</th>
	<th align="center">{{ report.portfolio.0.2 }}</th>
	<th align="center">{{ report.portfolio.0.3 }}</th>
	<th align="center">{{ report.portfolio.0.4 }}</th>
	<th align="center">{{ report.portfolio.0.5 }}</th>
	<th align="center" colspan="2">{{ report.portfolio.0.6 }}</th>
    </tr>
    </thead>
    <tbody>    
  {% for item in report.portfolio %}
    {% if forloop.first %}
    {% else %}        
    <tr>
	<td><a href="skg://Skrooge_operation_plugin/?operationWhereClause=t_UNIT='{{ item.0|encode }}'&title=Transactions with unit equal to '{{ item.1|encode }}'&title_icon=view-currency-list&currentPage=-1">{{ item.1 }} ({{ item.0 }})</a></td>
	<td>{{ item.2|safe }}</td>
	<td align="right">{{ item.3|money|safe }}</td>
	<td align="right">{{ item.4|money|safe }}</td>
	<td align="right">{{ item.5|money|safe }}</td>
	<td align="right">{{ item.6|money|safe }}</td>
	<td align="right">({{ item.7|percent|safe }})</td>
    </tr>
    {% endif %}          
  {% endfor %}  
    </tbody>
</table>
{% else %}
{{ msg_no_share|safe }}
{% endif %}
