<table id="table_categories_previous_period" class="table">
    <thead>
    <tr class="tabletitle">
	<th align="center">{{ report.categories_previous_period.0.1 }}</th>
	<th align="center">{{ report.categories_previous_period.0.2 }}</th>
	<th align="center">%</th>
    </tr>
    </thead>
    <tbody>    
{% for item in report.categories_previous_period %}
    {% if forloop.first %}
    {% else %}    
	<tr{% if item.0 %} class="tabletotal" {% endif %}>
	    <td>{{ forloop.counter0 }}: <a href="skg://Skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?operationTable=v_suboperation_consolidated&operationWhereClause={{ item.3|encode }}&title={{ item.1|encode }}/{{ report.categories_previous_period.0.2 }}&title_icon=applications-all-symbolic">{{ item.1 }}</a></td>
	    <td align="right">{{ item.2|money|safe }}</td>
	    <td align="right">{{ item.4|percent|safe }}</td>
	</tr>
    {% endif %}        
{% endfor %}     
    </tbody>
</table>   
