{{ report.advice|dump }}
<table id="table_advice" class="table">
    <thead>
    <tr class="tabletitle">
	<th align="center">Priority</th>
	<th align="center">Short message</th>
	<th align="center">Long message</th>
    </tr>
{% for item in report.advice %}  
      <tr{% if item.0 %} class="tabletotal" {% endif %}>
	  <td>{{ item.priority }}</td>
	  <td>{{ item.shortMessage|safe }}</td>
	  <td>{{ item.longMessage|safe }}</td>
      </tr>      
{% endfor %}   
    </tbody>
</table>   
