<table id="table_unit" class="table">
    <thead>
    <tr class="tabletitle">
	<th align="center">{{ report.unit_table.0.1 }}</th>
	<th align="center">{{ report.unit_table.0.2 }}</th>
	<th align="center">{{ report.unit_table.0.3 }}</th>
	<th align="center">{{ report.unit_table.0.4 }}</th>
    </tr>
    </thead>
    <tbody>
  {% for item in report.unit_table %}
    {% if forloop.first %}
    {% else %}        
    <tr>
	<td><a href="skg://Skrooge_operation_plugin/?operationWhereClause=t_UNIT='{{ item.5|encode }}'&title=Transactions with unit equal to '{{ item.1|encode }}'&title_icon=view-currency-list&currentPage=-1">{{ item.1 }} ({{ item.5 }})</a></td>
	<td align="right">{{ item.2|money|safe }}</td>
	<td align="right">{{ item.3|money|safe }}</td>
	<td align="right">{{ item.4|percent|safe }}</td>
    </tr>
    {% endif %}          
  {% endfor %}  
    </tbody>  
</table>