{% if report.bank_table %}
<table id="table_bank" class="table">
    <tbody>
{% for item in report.bank_table %}
    {% if forloop.first %}
	<tr>
	    <td><b>{{ item.1 }}</b></td>
	    <td><b>{{ item.6 }}</b></td>
	</tr>    
    {% else %}    
	<tr{% if item.0 %} class="tabletotal" {% endif %}>
	    <td>{% if item.0 %}<b>{{ item.1 }}</b>{% else %}<a href="skg://Skrooge_operation_plugin/?operationWhereClause=t_BANK='{{ item.1|encode }}'&title={{ item.1|encode }}&title_icon=view-bank-account">{{ item.1 }}</a>{% endif %}</td>
	    <td align="right">{% if item.0 %}<b>{% endif %}{{ item.6|money|safe }}{% if item.0 %}</b>{% endif %}</td>
	</tr>
    {% endif %}        
{% endfor %}     
    </tbody>
</table>   
{% endif %}   
