<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="skrooge_report" version="15" >
<MenuBar>
  <Menu name="go" noMerge="1"><text>Go</text>
	  <Action name="open_report" group="go_group_3"/>
	  <Menu name="other"><text>Other</text>
		  <Action name="view_open_very_old_operations" group="go_subgroup_2"/>
		  <Action name="view_open_very_far_operations" group="go_subgroup_2"/>		  
	  </Menu>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar"><text>Main Toolbar</text>
	<Action name="open_report" group="main_group_other"/>
</ToolBar>
</kpartgui>
