<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="skrooge_aiassistant" version="2">
<MenuBar>
  <Menu name="view">
    <Menu name="panels"><text>Panels</text>
      <Action name="view_aiassistant"/>
    </Menu>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar"><text>Main Toolbar</text>
</ToolBar>
</kpartgui>
