<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="skrooge_importexport" version="21">
<MenuBar>
  <Menu name="file"><text>File</text>
    <Menu name="import"><text>Import</text>
      <Action name="import_operation" />
      <Action name="import_backends" />
      <Action name="import_csv_unit" />
      <Action name="import_csv_rule" />
    </Menu>
    <Action name="export_operation" />
  </Menu>
  <Menu name="edit"><text>Edit</text>
	  <Action name="switch_validation_imported_operation" group="edit_group_1"/>
	  <Action name="merge_imported_operation" group="edit_group_1"/>
  </Menu>
  <Menu name="go"><text>Go</text>
	  <Action name="view_open_not_validated" group="go_group_3"/>
  </Menu>
  <Menu name="tool"><text>Tools</text>
	    <Action name="process_foundtransfer" group="tool_group_1"/>
	    <Action name="process_banks" group="tool_group_1"/>
	    <Action name="process_anonymize" group="tool_group_1"/>  
	    <Action name="process_validate" group="tool_group_2"/>  
  </Menu>    
</MenuBar>
<ToolBar name="mainToolBar"><text>Main Toolbar</text>
</ToolBar>
</kpartgui>
