<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="skgmainpanel" version="21">
<MenuBar>
  <Menu noMerge="1" name="file"><text>File</text>
    <Merge/>
    <Separator/>
    <Action name="file_quit"/>
  </Menu>
  <Menu noMerge="1" name="edit"><text>Edit</text>
	  <DefineGroup name="edit_group_undoredo"/>
	  <DefineGroup name="edit_group_copy"/>
	  <DefineGroup name="edit_group_select"/>
	  <DefineGroup name="edit_group_find"/>
	  <DefineGroup name="edit_group_1"/>
	  <DefineGroup name="edit_group_2"/>
  </Menu>
  <Menu noMerge="1" name="view"><text>View</text>
	  <Action name="enable_editor"/>
	  <Separator/>
	  <Action name="new_tab"/>
          <Action name="tab_reopenlastclosed"/>
	  <Action name="tab_close"/>
	  <Action name="tab_closeall"/>
	  <Action name="tab_closeallother"/>
	  <Separator/>
	  <Action name="tab_switchpin"/>	  
	  <Action name="tab_resetdefaultstate"/>
	  <Action name="tab_savedefaultstate"/>
	  <Action name="tab_overwritebookmark"/>
	  <Separator/>
	  <Menu name="panels"><text>Panels</text>
	  	<Action name="view_messages"/>
	  	<Action name="view_context"/>
		<Merge/>
		<Separator/>
	  	<Action name="view_lock"/>
	  	<Action name="view_unlock"/>
	  </Menu>
          <Separator/>
          <Action name="fullscreen"/>
  </Menu>
  <Menu noMerge="1" name="go"><text>Go</text>
	  <Action name="view_contextmenu"/>
	  <DefineGroup name="go_group_1"/>
	  <Separator/>
	  <DefineGroup name="go_group_2"/>
	  <Action name="go_previous"/>
	  <Action name="go_next"/>
	  <DefineGroup name="go_group_3"/>	
	  <Menu name="other"><text>Other</text>
	    <DefineGroup name="go_subgroup_1"/>
	    <Separator/>
	    <DefineGroup name="go_subgroup_2"/>
	    <Separator/>
	    <DefineGroup name="go_subgroup_3"/>
	  </Menu>		  
  </Menu>
  <Menu noMerge="1" name="tool"><text>Tools</text>
	  <DefineGroup name="tool_group_1"/>
	  <Separator/>
	  <DefineGroup name="tool_group_2"/>
  </Menu>  
</MenuBar>
<ToolBar noMerge="1" name="mainToolBar"><text>Main Toolbar</text>
  <DefineGroup name="main_group_file"/>
  <Merge/>
  <Separator/>
  <DefineGroup name="main_group_nav1"/>
  <Action name="go_previous"/>
  <Action name="go_next"/>
  <DefineGroup name="main_group_nav2"/>
  <Merge/>
  <Separator/>
  <DefineGroup name="main_group_undoredo"/>
  <Merge/>
  <Separator/>
  <DefineGroup name="main_group_edit"/>
  <Merge/>
  <Separator/>
  <DefineGroup name="main_group_other"/>
  <Merge/>
</ToolBar>
<ToolBar noMerge="1" name="context" hidden="true" position="left" iconText="icontextbottom"><text>Pages</text>
  <ActionList name="context_actionlist"/>
</ToolBar>
</kpartgui>
