<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="skrooge_operation" version="17">
<MenuBar>
  <Menu name="edit"><text>Edit</text>
	  <Action name="fast_edition" group="edit_group_find"/>
	  <Action name="edit_switch_highlight" group="edit_group_1"/>
	  <Action name="edit_mark_selected_operation" group="edit_group_1"/>
	  <Action name="edit_check_selected_operation" group="edit_group_1"/>
	  <Action name="edit_group_operation" group="edit_group_1"/>
	  <Action name="edit_ungroup_operation" group="edit_group_1"/>
	  <Action name="edit_duplicate_operation" group="edit_group_1"/>
	  <Action name="edit_template_operation" group="edit_group_1"/>
          <Action name="edit_apply_template" group="edit_group_1"/>          
          <Action name="merge_sub_operations" group="edit_group_1"/>
  </Menu>
  <Menu name="go"><text>Go</text>
	  <Separator group="go_group_3"/>
	  <Action name="view_open_highlight" group="go_group_3"/>
	  <Action name="view_open_last_modified" group="go_group_3"/>
	  <Action name="view_open_duplicates" group="go_group_3"/>
	  <Action name="view_open_suboperations" group="go_group_3"/>
	  <Menu name="other"><text>Other</text>
		  <Action name="view_open_operation_without_category" group="go_subgroup_1"/>
		  <Action name="view_open_transfers_without_category" group="go_subgroup_1"/>
		  <Action name="view_open_operation_without_payee" group="go_subgroup_1"/>
		  <Action name="view_open_transfers_without_payee" group="go_subgroup_1"/>
		  <Action name="view_open_suboperations_without_payee_category" group="go_subgroup_1"/>
		  <Action name="view_open_operation_without_mode" group="go_subgroup_1"/>
                  <Action name="view_open_operation_with_date_not_aligned" group="go_subgroup_2"/>
                  <Action name="view_open_operation_with_comment_not_aligned" group="go_subgroup_2"/>
		  <Action name="view_open_operation_in_group_of_one" group="go_subgroup_2"/>
	  </Menu>	  
  </Menu>
  <Menu name="tool"><text>Tools</text>
	  <Action name="align_comment" group="tool_group_2"/>
          <Action name="align_date" group="tool_group_2"/>
	  <Action name="align_category" group="tool_group_2"/>
          <Action name="clean_remove_group_with_one_operation" group="tool_group_2"/>
  </Menu>   
</MenuBar>
<ToolBar name="mainToolBar"><text>Main Toolbar</text>
</ToolBar>
</kpartgui>
