<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="skg_undoredo" version="4">
<MenuBar>
  <Menu name="edit"><text>Edit</text>
	  <Action name="edit_undo" group="edit_group_undoredo"/>
	  <Action name="edit_redo" group="edit_group_undoredo"/>
	  <Separator/>
	  <Action name="edit_undolastsave" group="edit_group_undoredo"/>
	  <Separator group="edit_group_undoredo"/>
  </Menu>
  <Menu name="view">
	<Menu name="panels"><text>Panels</text>
		<Action name="view_transactions"/>
  	</Menu>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar"><text>Main Toolbar</text>
	<Action name="edit_undo" group="main_group_undoredo"/>
	<Action name="edit_redo" group="main_group_undoredo"/>
</ToolBar>
</kpartgui>
